==> Cosmos.uv3.50.tar.gz: cosmos/Zprimary.h <==
c                this is Primary class data type definition
c         Note that primary angle information is not here.
c
         integer NoOfSymbols,   ! max # of primary type symbols
     *           maxSegments,    ! max # of segments in each primary
     *           maxNoOfComps,  ! max # of components usable
c                                        at a time 
     *           maxErgUnit       ! max # of energy unit symbols
         parameter (NoOfSymbols = 44, 
     *              maxSegments = 40, 
     *              maxNoOfComps = 8,
     *              maxErgUnit=7 )
c
         structure /component/     ! 1 component of 1ry 
             integer label          ! composition label number
             character*12 symb        ! 'P', 'gamma' etc
             character*3 eunit        ! 'GeV' etc
             character*4 etype        ! 'KE/n' etc
             character*1 diff_or_inte   ! 'd' or 'i'
             real*8 flatterer               ! dI/dE*E**flatterer
             real*8 energy(maxSegments+1)  ! segment left energy
             real*8 flux(maxSegments+1)    ! input flux
c                                            dI/dE * E**flatterer
c                          above: from  input table directly
c                          below: made by subroutines
             integer code, subcode, charge  ! particle code
             real*8 togev

c!!!!        real*8 diff(maxSegments+1)      ! diff. flux
             real*8 norm_inte(maxSegments+1) ! normalized 
c                      integral flux > E at segment left value
             real*8 beta(maxSegments+1)    ! dI/dE=(true flux)=
c                                            const*E**(-beta)
             integer no_of_seg         ! no of segments given
             real*8 inte_value       !  integral flux from min. E
             real*8 emin, emax     ! min and max energy defined
c            integer histnbin
c            parameter (histnbin = 30)
c            record /histgl/ comphist
         end structure    
c         *******************************************
         structure /primaries/   ! 1 set of primaries.
              record /component/ each(maxNoOfComps)
              real*8 cummInteFlux(maxNoOfComps)
              integer no_of_comps    ! how many diff. compositions
              integer NoOfSamplings  ! how many times sampled
c                        after a sampling of a 1ry, the following 
c                        is fixed.
              integer label            ! sampled primary label
              real*8 sampled_e     ! sampled energy(or momentum) as
c                                    defined in etype. If this is
c                                    in total energy in GeV, it is the
c                                    same as particle.fm.e
              record /ptcl/ particle
         end structure

==> Cosmos.uv5.03.tar.gz: cosmos/Zprimary.h <==
#include "Zmaxdef.h"

c                this is Primary class data type definition
c         Note that primary angle information is not here.
c
         integer NoOfSymbols,   ! max # of primary type symbols
     *           maxSegments,    ! max # of segments in each primary
     *           maxNoOfComps,  ! max # of components usable
c                                        at a time 
     *           maxErgUnit       ! max # of energy unit symbols
         parameter (NoOfSymbols = 44, 
#ifdef MAX_SEGMENTS
     *              maxSegments = MAX_SEGMENTS,
#else
     *              maxSegments = 40, 
#endif
#ifdef MAX_NO_OF_COMPS
     *              maxNoOfComps = MAX_NO_OF_COMPS,
#else
     *              maxNoOfComps = 8,
#endif
     *              maxErgUnit=7 )
c
         structure /component/     ! 1 component of 1ry 
             integer label          ! composition label number
             character*12 symb        ! 'P', 'gamma' etc
             character*3 eunit        ! 'GeV' etc
             character*4 etype        ! 'KE/n' etc
             character*1 diff_or_inte   ! 'd' or 'i'
             real*8 flatterer               ! dI/dE*E**flatterer
             real*8 cut                  !  lower cut off.
             real*8 energy(maxSegments+1)  ! segment left energy
             real*8 flux(maxSegments+1)    ! input flux
c                                            dI/dE * E**flatterer
c                          above: from  input table directly
c                          below: made by subroutines
             integer code, subcode, charge  ! particle code
             real*8 togev

c!!!!        real*8 diff(maxSegments+1)      ! diff. flux
             real*8 norm_inte(maxSegments+1) ! normalized 
c                      integral flux > E at segment left value
             real*8 beta(maxSegments+1)    ! dI/dE=(true flux)=
c                                            const*E**(-beta)
             integer no_of_seg         ! no of segments given
             real*8 inte_value       !  integral flux from min. E
             real*8 emin, emax     ! min and max energy defined
c            integer histnbin
c            parameter (histnbin = 30)
c            record /histgl/ comphist
         end structure    
c         *******************************************
         structure /primaries/   ! 1 set of primaries.
              record /component/ each(maxNoOfComps)
              real*8 cummInteFlux(maxNoOfComps)
              integer no_of_comps    ! how many diff. compositions
              integer NoOfSamplings  ! how many times sampled
c                        after a sampling of a 1ry, the following 
c                        is fixed.
              integer label            ! sampled primary label
              real*8 sampled_e     ! sampled energy(or momentum) as
c                                    defined in etype. If this is
c                                    in total energy in GeV, it is the
c                                    same as particle.fm.e
              record /ptcl/ particle
         end structure
